@@ -409,8 +409,11 @@ parse_hkp_index (const gchar *response)
     
 	for (l = lines; *l; l++) {
 
-		line = *l;
+		line = *l;	
 		dehtmlize (line);
+#if DEBUG_HKP_ENABLE
+        fprintf(stderr,"%s\n", line);
+#endif
 
 		/* Start a new key */
 		if (g_ascii_strncasecmp (line, "pub ", 4) == 0) {
@@ -519,9 +522,9 @@ parse_hkp_index (const gchar *response)
 	g_strfreev (lines);
 
 	if (key) {
-		seahorse_pgp_key_set_uids (SEAHORSE_PGP_KEY (key), uids);
+		seahorse_pgp_key_set_uids (SEAHORSE_PGP_KEY (key), g_list_reverse (uids));
 		seahorse_object_list_free (uids);
-		seahorse_pgp_key_set_subkeys (SEAHORSE_PGP_KEY (key), subkeys);
+		seahorse_pgp_key_set_subkeys (SEAHORSE_PGP_KEY (key), g_list_reverse (subkeys));
 		seahorse_object_list_free (subkeys);
 	}
 	
@@ -534,7 +537,7 @@ add_key (SeahorseHKPSource *ssrc, SeahorsePgpKey *key)
 	SeahorseObject *prev;
 	GQuark keyid;
        
-	keyid = seahorse_pgp_key_calc_cannonical_id (seahorse_pgp_key_get_keyid (key));
+	keyid = seahorse_pgp_key_canonize_id (seahorse_pgp_key_get_keyid (key));
 	prev = seahorse_context_get_object (SCTX_APP (), SEAHORSE_SOURCE (ssrc), keyid);
 	if (prev != NULL) {
 		g_return_if_fail (SEAHORSE_IS_PGP_KEY (prev));
@@ -731,9 +734,8 @@ get_callback (SoupSession *session, SoupMessage *msg, SeahorseHKPOperation *hop)
 
 enum {
     PROP_0,
-    PROP_KEY_TYPE,
-    PROP_KEY_DESC,
-    PROP_LOCATION
+    PROP_SOURCE_TAG,
+    PROP_SOURCE_LOCATION
 };
 
 static void seahorse_source_iface (SeahorseSourceIface *iface);
@@ -752,13 +754,10 @@ seahorse_hkp_source_get_property (GObject *object, guint prop_id, GValue *value,
                                   GParamSpec *pspec)
 {
     switch (prop_id) {
-    case PROP_KEY_TYPE:
+    case PROP_SOURCE_TAG:
         g_value_set_uint (value, SEAHORSE_PGP);
         break;
-    case PROP_KEY_DESC:
-        g_value_set_string (value, _("PGP Key"));
-        break;
-    case PROP_LOCATION:
+    case PROP_SOURCE_LOCATION:
         g_value_set_enum (value, SEAHORSE_LOCATION_REMOTE);
         break;
     };        
@@ -771,6 +770,25 @@ seahorse_hkp_source_set_property (GObject *object, guint prop_id, const GValue *
 
 }
 
+static gboolean
+is_hex_keyid (const gchar *match)
+{
+    const gchar *t;
+    
+    t = match;
+    
+    if (strlen (match) != 8)
+        return FALSE;
+    
+    while (*t != NULL) {
+        if (!((*t >= 0x30 && *t <= 0x39) || (*t >= 0x41 && *t <= 0x46) || (*t >= 0x61 && *t <= 0x66)))
+            return FALSE;
+            
+        t++;
+    }
+    
+    return TRUE;
+}
 
 static SeahorseOperation*
 seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
@@ -780,6 +798,7 @@ seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
     GHashTable *form;
     gchar *t;
     SoupURI *uri;
+    gchar hexfpr[11];
     
     g_assert (SEAHORSE_IS_SOURCE (src));
     g_assert (SEAHORSE_IS_HKP_SOURCE (src));
@@ -791,7 +810,15 @@ seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
     
     form = g_hash_table_new (g_str_hash, g_str_equal);
     g_hash_table_insert (form, "op", "index");
-    g_hash_table_insert (form, "search", (char *)match);
+    
+    if (is_hex_keyid (match)) {
+        strncpy (hexfpr, "0x", 3);
+        strncpy (hexfpr + 2, match, 9);
+        
+        g_hash_table_insert (form, "search", hexfpr);
+    } else 
+        g_hash_table_insert (form, "search", (char *)match);
+        
     soup_uri_set_query_from_form (uri, form);
     g_hash_table_destroy (form);
     
@@ -971,14 +998,13 @@ seahorse_hkp_source_class_init (SeahorseHKPSourceClass *klass)
 	
 	seahorse_hkp_source_parent_class = g_type_class_peek_parent (klass);
 
-	g_object_class_override_property (gobject_class, PROP_KEY_TYPE, "key-type");
-	g_object_class_override_property (gobject_class, PROP_KEY_DESC, "key-desc");
-	g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_TAG, "source-tag");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_LOCATION, "source-location");
 
 	seahorse_registry_register_type (NULL, SEAHORSE_TYPE_HKP_SOURCE, "source", "remote", SEAHORSE_PGP_STR, NULL);
 	seahorse_servers_register_type ("hkp", _("HTTP Key Server"), seahorse_hkp_is_valid_uri);
 	
-	seahorse_registry_register_function (NULL, seahorse_pgp_key_calc_cannonical_id, "canonize", SEAHORSE_PGP_STR, NULL);
+	seahorse_registry_register_function (NULL, seahorse_pgp_key_canonize_id, "canonize", SEAHORSE_PGP_STR, NULL);
 }
 
 static void 
@@ -1036,7 +1062,7 @@ seahorse_hkp_is_valid_uri (const gchar *uri)
         /* Must be http or https, have a host. No querystring, user, path, passwd etc... */
         if ((soup->scheme == SOUP_URI_SCHEME_HTTP || soup->scheme == SOUP_URI_SCHEME_HTTPS) && 
             !soup->user && !soup->password && !soup->query && !soup->fragment &&
-            g_str_equal (soup->path, "/"))
+            soup->host && g_str_equal (soup->path ? soup->path : "/", "/"))
             ret = TRUE;
         soup_uri_free (soup);
     }
